from distutils.core import setup

setup(
    name='django-networth',
    version='0.5',
    packages=['networth'],
    url='https://github.com/Hedde/django-networth',
    license='MIT',
    author='Hedde van der Heide',
    author_email='me@heddevanderheide.nl',
    description='Valuate instances of Django Models.'
)